@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 ### System ###
 import os
 from glob import glob
@@ -18,8 +19,13 @@ class CleanTask:
         self.config = config
 
     def post_build(self):
+        if self.config["renutil"]["registry"]:
+            registry_cmd = "-r '{}'".format(self.config["renutil"]["registry"])
+
         run(
-            "renutil clean {}".format(self.config["renutil"]["version"]),
+            "renutil {} clean {}".format(
+                registry_cmd, self.config["renutil"]["version"]
+            ),
             capture_output=True,
             shell=True,
         )
